@@ -29,6 +29,12 @@ def oracle_calculator(contract, marketplaces, start, end):
     end_hours, start_hours = random_range(end, start)
     price_entries = fetchData(contract, marketplaces, start_hours, end_hours)
 
+    if isinstance(price_entries, str):
+        # Not enough volume
+        return 0, 0
+
+    print(price_entries)
+
     log_returns = [math.log(number) for number in price_entries]
     volatility = np.std(log_returns) * 100
 
@@ -66,7 +72,7 @@ def oracle_calculator(contract, marketplaces, start, end):
     print('Final price list: ')
     print(prices)
 
-    final_price = np.format_float_positional(average_list(prices), trim='-')
+    final_price = int(np.format_float_positional(average_list(prices), trim='-'))
 
     if not os.path.exists("./cache"):
         # Create a new directory because it does not exist
